Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var JobQueue chan Job
A buffered channel that we can send work requests on.
Functions ¶
This section is empty.
Types ¶
type Dispatcher ¶
type Dispatcher struct {
// A pool of workers channels that are registered with the dispatcher
MaxWorkers int
WorkerPool chan chan Job
}
func NewDispatcher ¶
func NewDispatcher(maxWorkers int) *Dispatcher
func (*Dispatcher) Run ¶
func (d *Dispatcher) Run()
type Message ¶
type Message struct {
OpenID string
ReqID string
TemplateID string
Page string
Key1 string
Value1 string
Key2 string
Value2 string
Key3 string
Value3 string
Key4 string
Value4 string
Key5 string
Value5 string
AccessToken string
}
Message struct 小程序订阅消息推送
type PlayerDemo ¶
PlayerDemo struct 示例结构
type Template ¶
type Template struct {
OpenID string
ReqID string
TemplateID string
PageURL string
MiniprogramAppID string
MiniprogramPagePath string
ClientMSGID string
Key1 string
Value1 string
Color1 string
Key2 string
Value2 string
Color2 string
Key3 string
Value3 string
Color3 string
Key4 string
Value4 string
Color4 string
Key5 string
Value5 string
Color5 string
AccessToken string
}
Template struct 服务号模板消息推送
type Worker ¶
type Worker struct {
WorkerPool chan chan Job
JobChannel chan Job
// contains filtered or unexported fields
}
Worker represents the worker that executes the job
Click to show internal directories.
Click to hide internal directories.